@@ -12,17 +12,19 @@ class PROXIES:
         '''神龙代理'''
         for _ in range(3):
             try:
-                rsp = requests.get(url="http://api.shenlongip.com/ip?key="+settings.proxiesKey+"&pattern=txt&count=1&protocol=2",timeout=5)
+                rsp = requests.get(
+                    url="http://api.shenlongip.com/ip?key=" + settings.proxiesKey + "&pattern=txt&count=1&protocol=2",
+                    timeout=5)
                 code = rsp.status_code
                 r = rsp.text.strip()
                 if "白名单" in r:
-                    return {"code":400,"message":r,"proxies":""}
+                    return {"code": 400, "message": r, "proxies": ""}
                 elif code == 200:
                     proxies = {"https": "http://" + r,
                                "http": "http://" + r}
-                    return {"code":200,"message":"success","proxies":proxies}
+                    return {"code": 200, "message": "success", "proxies": proxies}
                 else:
-                    return {"code":401,"message":r,"proxies":""}
+                    return {"code": 401, "message": r, "proxies": ""}
             except:
                 return {"code": 500,
                         "message": 'failed to Obtain ip,try again',
@@ -36,7 +38,7 @@ class PROXIES:
             "user": settings.proxyUser,
             "pass": settings.proxyPass,
         }
-        proxies ={
+        proxies = {
             "http": proxyMeta,
             "https": proxyMeta,
         }
